from ..models.point3d import Point3d
from .base import KittyCadBaseModel


class GetSketchModePlane(KittyCadBaseModel):
    """The plane for sketch mode."""

    origin: Point3d

    x_axis: Point3d

    y_axis: Point3d

    z_axis: Point3d
